==> nextcloud-13.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/ja.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "ストレージは一時的に利用できません",
    "Storage invalid" : "ストレージが無効です",
    "Unknown error" : "不明なエラー",
    "All files" : "すべてのファイル",
    "Recent" : "最新",
    "Favorites" : "お気に入り",
    "File could not be found" : "ファイルを見つけられませんでした",
    "Move or copy" : "移動またはコピー",
    "Download" : "ダウンロード",
    "Delete" : "削除",
    "Home" : "ホーム",
    "Close" : "閉じる",
    "Could not create folder \"{dir}\"" : "フォルダー \"{dir}\" を作成できませんでした",
    "Upload cancelled." : "アップロードはキャンセルされました。",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "ディレクトリであるか、または0バイトのため {filename} をアップロードできません",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "空き容量が十分でなく、 {size1} をアップロードしていますが、 {size2} しか残っていません。",
    "Target folder \"{dir}\" does not exist any more" : "対象フォルダー \"{dir}\" がもう存在しません",
    "Not enough free space" : "十分な空き容量がありません",
    "Uploading …" : "アップロード中...",
    "…" : "…",
    "{loadedSize} of {totalSize} ({bitrate})" : "{totalSize} 中 {loadedSize} ({bitrate})",
    "Target folder does not exist any more" : "対象フォルダーがもう存在しません",
    "Actions" : "アクション",
    "Rename" : "名前の変更",
    "Target folder" : "対象フォルダー",
    "Disconnect storage" : "ストレージを切断する",
    "Unshare" : "共有解除",
    "Could not load info for file \"{file}\"" : "\"{file}\" ファイルの情報を読み込めませんでした",
    "Files" : "ファイル",
    "Details" : "詳細",
    "Select" : "選択",
    "Pending" : "中断",
    "Unable to determine date" : "更新日不明",
    "This operation is forbidden" : "この操作は禁止されています",
    "This directory is unavailable, please check the logs or contact the administrator" : "このディレクトリは利用できません。ログを確認するか管理者に問い合わせてください。",
    "Could not move \"{file}\", target exists" : "ターゲットが存在するため，ファイル \"{file}\"を移動できませんでした",
    "Could not move \"{file}\"" : "\"{file}\" を移動できませんでした",
    "Could not copy \"{file}\", target exists" : "ターゲットが存在するため，ファイル \"{file}\"をコピーできませんでした",
    "Could not copy \"{file}\"" : "\"{file}\"をコピーできませんでした",
    "{newName} already exists" : "{newName} はすでに存在します",
    "Could not rename \"{fileName}\", it does not exist any more" : "ファイルが存在しないため,\"{fileName}\"の名前変更ができませんでした",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{targetName}\" はフォルダー \"{dir}\" ですでに使われています。別の名前を選択してください。",
    "Could not rename \"{fileName}\"" : "\"{fileName}\"の名前変更ができませんでした",
    "Could not create file \"{file}\"" : "ファイル \"{file}\" を作成できませんでした",
    "Could not create file \"{file}\" because it already exists" : "ファイル \"{file}\"はすでに存在するため作成できません",
    "Could not create folder \"{dir}\" because it already exists" : "フォルダー \"{dir}\" はすでに存在するため作成できません",
    "Error deleting file \"{fileName}\"." : "ファイル\"{fileName}\"の削除エラー。",
    "No search results in other folders for {tag}{filter}{endtag}" : "他のフォルダーに {tag}{filter}{endtag} の検索結果はありません",
    "Name" : "名前",
    "Size" : "サイズ",
    "Modified" : "更新日時",
    "_%n folder_::_%n folders_" : ["%n 個のフォルダー"],
    "_%n file_::_%n files_" : ["%n 個のファイル"],
    "{dirs} and {files}" : "{dirs} と {files}",
    "_including %n hidden_::_including %n hidden_" : ["%n 個の隠しファイルが含まれています"],
    "You don’t have permission to upload or create files here" : "ここにファイルをアップロードまたは作成する権限がありません",
    "_Uploading %n file_::_Uploading %n files_" : ["%n 個のファイルをアップロード中"],
    "New" : "新規作成",
    "{used} of {quota} used" : "{used} / {quota} 使用中",
    "{used} used" : "{used} 使用中",
    "\"{name}\" is an invalid file name." : "\"{name}\" は無効なファイル名です。",
    "File name cannot be empty." : "ファイル名を空にすることはできません。",
    "\"/\" is not allowed inside a file name." : "\"/\" はファイル名に利用できません。",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" は無効なファイル形式です",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} のストレージは一杯です。ファイルの更新と同期はもうできません！",
    "Your storage is full, files can not be updated or synced anymore!" : "あなたのストレージは一杯です。ファイルの更新と同期はもうできません！",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} のストレージはほぼ一杯です。({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "ストレージがほぼ一杯です（{usedSpacePercent}%）",
    "_matches '{filter}'_::_match '{filter}'_" : [" '{filter}' にマッチ"],
    "View in folder" : "フォルダー内で表示",
    "Copied!" : "コピー完了",
    "Copy direct link (only works for users who have access to this file/folder)" : "ダイレクトリンクをコピー (このファイル/フォルダーにアクセスできるユーザーのみ)",
    "Path" : "Path",
    "_%n byte_::_%n bytes_" : ["%n バイト"],
    "Favorited" : "お気に入り済",
    "Favorite" : "お気に入り",
    "New folder" : "新しいフォルダー",
    "Upload file" : "ファイルをアップロード",
    "Not favorited" : "お気に入りではありません",
    "Remove from favorites" : "お気に入りから削除",
    "Add to favorites" : "お気に入りに追加",
    "An error occurred while trying to update the tags" : "タグを更新する際にエラーが発生しました",
    "Added to favorites" : "お気に入りに追加",
    "Removed from favorites" : "お気に入りから削除",
    "You added {file} to your favorites" : "{file} をお気に入りに追加しました",
    "You removed {file} from your favorites" : "{file} をお気に入りから削除しました",
    "File changes" : "ファイル更新",
    "Created by {user}" : "{user} が作成しました",
    "Changed by {user}" : "{user} が更新しました",
    "Deleted by {user}" : "{user} が削除しました",
    "Restored by {user}" : "{user} が復元しました",
    "Renamed by {user}" : "{user} が作成しました",
    "Moved by {user}" : "{user} が移動しました",
    "\"remote user\"" : "\"リモートユーザー\"",
    "You created {file}" : "{file} を作成しました",
    "You created an encrypted file in {file}" : "{file} で暗号化ファイルを作成しました",
    "{user} created {file}" : "{user} が {file} を作成しました",
    "{file} was created in a public folder" : "公開フォルダーに {file} が作成されました",
    "You changed {file}" : "{file} を更新しました",
    "{user} changed {file}" : "{user} が {file} を更新しました",
    "You deleted {file}" : "{file} を削除しました",
    "{user} deleted {file}" : "{user} が {file} を削除しました",
    "You restored {file}" : "{file} を復元しました",
    "{user} restored {file}" : "{user} が {file} を復元しました",
    "You renamed {oldfile} to {newfile}" : "{oldfile} を {newfile} に変更しました",
    "{user} renamed {oldfile} to {newfile}" : "{user} が {oldfile} を{newfile} に変更しました",
    "You moved {oldfile} to {newfile}" : "{oldfile} を {newfile} に移動しました",
    "{user} moved {oldfile} to {newfile}" : "{user} が {oldfile} を {newfile} に移動しました",
    "A file has been added to or removed from your <strong>favorites</strong>" : "<strong>お気に入り</strong>にファイルが追加または削除されたとき",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "ファイルまたはフォルダーが<strong>更新</ strong>されたか、<strong>名前が変更</strong>されたとき",
    "A new file or folder has been <strong>created</strong>" : "新しいファイルまたはフォルダーが<strong>作成</strong>されたとき",
    "A file or folder has been <strong>deleted</strong>" : "ファイルまたはフォルダーが<strong>削除</strong>されたとき",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "<strong>お気に入りファイル</strong>の作成と変更の通知を制限する<em>（ストリームのみ）</em>",
    "A file or folder has been <strong>restored</strong>" : "ファイルまたはフォルダーが<strong>復元</strong>されたとき",
    "Unlimited" : "無制限",
    "Upload (max. %s)" : "アップロード ( 最大 %s )",
    "File handling" : "ファイル操作",
    "Maximum upload size" : "最大アップロードサイズ",
    "max. possible: " : "最大容量: ",
    "Save" : "保存",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "PHP-FPM の場合は値を変更後、反映されるのに5分程度かかります。",
    "Missing permissions to edit from here." : "ここから編集するための権限がありません。",
    "%s of %s used" : "%s / %s 使用中",
    "%s used" : "%s 使用中",
    "Settings" : "設定",
    "Show hidden files" : "隠しファイルを表示",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">WebDAV 経由でファイルにアクセス</a>するにはこのアドレスを利用してください",
    "Cancel upload" : "アップロードをキャンセル",
    "No files in here" : "ファイルがありません",
    "Upload some content or sync with your devices!" : "何かコンテンツをアップロードするか、デバイスからファイルを同期してください。",
    "No entries found in this folder" : "このフォルダーにはエントリーがありません",
    "Select all" : "すべて選択",
    "Upload too large" : "アップロードには大きすぎます。",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "アップロードしようとしているファイルは、このサーバーのファイルアップロード時の最大サイズを超えています。",
    "No favorites yet" : "まだお気に入りはありません",
    "Files and folders you mark as favorite will show up here" : "お気に入りに登録されたファイルやフォルダーは、ここに表示されます。",
    "Tags" : "タグ",
    "Deleted files" : "ゴミ箱",
    "Text file" : "テキストファイル",
    "New text file.txt" : "新規のテキストファイル作成",
    "Move" : "移動",
    "Shared with you" : "他ユーザーがあなたと共有中",
    "Shared with others" : "他ユーザーと共有中",
    "Shared by link" : "URLリンクで共有中"
},
"nplurals=1; plural=0;");

==> nextcloud-15.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/ja.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "ストレージは一時的に利用できません",
    "Storage invalid" : "ストレージが無効です",
    "Unknown error" : "不明なエラー",
    "All files" : "すべてのファイル",
    "Recent" : "最新",
    "Favorites" : "お気に入り",
    "File could not be found" : "ファイルを見つけられませんでした",
    "Move or copy" : "移動またはコピー",
    "Download" : "ダウンロード",
    "Delete" : "削除",
    "Home" : "ホーム",
    "Close" : "閉じる",
    "Could not create folder \"{dir}\"" : "フォルダー \"{dir}\" を作成できませんでした",
    "This will stop your current uploads." : "現在のアップロードが停止されます。",
    "Upload cancelled." : "アップロードはキャンセルされました。",
    "…" : "…",
    "Processing files …" : "ファイルの処理中...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "ディレクトリであるか、または0バイトのため {filename} をアップロードできません",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "空き容量が十分でなく、 {size1} をアップロードしていますが、 {size2} しか残っていません。",
    "Target folder \"{dir}\" does not exist any more" : "対象フォルダー \"{dir}\" がもう存在しません",
    "Not enough free space" : "十分な空き容量がありません",
    "An unknown error has occurred" : "不明なエラーが発生しました",
    "Uploading …" : "アップロード中...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{totalSize} 中 {loadedSize} ({bitrate})",
    "Uploading that item is not supported" : "そのアイテムのアップロードはサポートされていません",
    "Target folder does not exist any more" : "対象フォルダーがもう存在しません",
    "Error when assembling chunks, status code {status}" : "チャンクを組み立てる際のエラー、ステータスコード{status}",
    "Actions" : "アクション",
    "Rename" : "名前の変更",
    "Copy" : "コピー",
    "Choose target folder" : "ターゲットフォルダを選択",
    "Disconnect storage" : "ストレージを切断する",
    "Unshare" : "共有解除",
    "Could not load info for file \"{file}\"" : "\"{file}\" ファイルの情報を読み込めませんでした",
    "Files" : "ファイル",
    "Details" : "詳細",
    "Select" : "選択",
    "Pending" : "中断",
    "Unable to determine date" : "更新日不明",
    "This operation is forbidden" : "この操作は禁止されています",
    "This directory is unavailable, please check the logs or contact the administrator" : "このディレクトリは利用できません。ログを確認するか管理者に問い合わせてください。",
    "Could not move \"{file}\", target exists" : "ターゲットが存在するため，ファイル \"{file}\"を移動できませんでした",
    "Could not move \"{file}\"" : "\"{file}\" を移動できませんでした",
    "copy" : "コピー",
    "Could not copy \"{file}\", target exists" : "ターゲットが存在するため，ファイル \"{file}\"をコピーできませんでした",
    "Could not copy \"{file}\"" : "\"{file}\"をコピーできませんでした",
    "Copied {origin} inside {destination}" : "コピー先{origin} {destination}内",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "コピー先{origin}と{nbfiles}他のファイル{destination}",
    "{newName} already exists" : "{newName} はすでに存在します",
    "Could not rename \"{fileName}\", it does not exist any more" : "ファイルが存在しないため,\"{fileName}\"の名前変更ができませんでした",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{targetName}\" はフォルダー \"{dir}\" ですでに使われています。別の名前を選択してください。",
    "Could not rename \"{fileName}\"" : "\"{fileName}\"の名前変更ができませんでした",
    "Could not create file \"{file}\"" : "ファイル \"{file}\" を作成できませんでした",
    "Could not create file \"{file}\" because it already exists" : "ファイル \"{file}\"はすでに存在するため作成できません",
    "Could not create folder \"{dir}\" because it already exists" : "フォルダー \"{dir}\" はすでに存在するため作成できません",
    "Error deleting file \"{fileName}\"." : "ファイル\"{fileName}\"の削除エラー。",
    "No search results in other folders for {tag}{filter}{endtag}" : "他のフォルダーに {tag}{filter}{endtag} の検索結果はありません",
    "Name" : "名前",
    "Size" : "サイズ",
    "Modified" : "更新日時",
    "_%n folder_::_%n folders_" : ["%n 個のフォルダー"],
    "_%n file_::_%n files_" : ["%n 個のファイル"],
    "{dirs} and {files}" : "{dirs} と {files}",
    "_including %n hidden_::_including %n hidden_" : ["%n 個の隠しファイルが含まれています"],
    "You don’t have permission to upload or create files here" : "ここにファイルをアップロードまたは作成する権限がありません",
    "_Uploading %n file_::_Uploading %n files_" : ["%n 個のファイルをアップロード中"],
    "New" : "新規作成",
    "{used} of {quota} used" : "{used} / {quota} 使用中",
    "{used} used" : "{used} 使用中",
    "\"{name}\" is an invalid file name." : "\"{name}\" は無効なファイル名です。",
    "File name cannot be empty." : "ファイル名を空にすることはできません。",
    "\"/\" is not allowed inside a file name." : "\"/\" はファイル名に利用できません。",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" は無効なファイル形式です",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} のストレージは一杯です。ファイルの更新と同期はもうできません！",
    "Your storage is full, files can not be updated or synced anymore!" : "あなたのストレージは一杯です。ファイルの更新と同期はもうできません！",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} のストレージはほぼ一杯です。({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "ストレージがほぼ一杯です（{usedSpacePercent}%）",
    "_matches '{filter}'_::_match '{filter}'_" : [" '{filter}' にマッチ"],
    "View in folder" : "フォルダー内で表示",
    "Copied!" : "コピー完了",
    "Copy direct link (only works for users who have access to this file/folder)" : "ダイレクトリンクをコピー (このファイル/フォルダーにアクセスできるユーザーのみ)",
    "Path" : "Path",
    "_%n byte_::_%n bytes_" : ["%n バイト"],
    "Favorited" : "お気に入り済",
    "Favorite" : "お気に入り",
    "New folder" : "新しいフォルダー",
    "Upload file" : "ファイルをアップロード",
    "Not favorited" : "お気に入りではありません",
    "Remove from favorites" : "お気に入りから削除",
    "Add to favorites" : "お気に入りに追加",
    "An error occurred while trying to update the tags" : "タグを更新する際にエラーが発生しました",
    "Added to favorites" : "お気に入りに追加",
    "Removed from favorites" : "お気に入りから削除",
    "You added {file} to your favorites" : "{file} をお気に入りに追加しました",
    "You removed {file} from your favorites" : "{file} をお気に入りから削除しました",
    "File changes" : "ファイル更新",
    "Created by {user}" : "{user} が作成しました",
    "Changed by {user}" : "{user} が更新しました",
    "Deleted by {user}" : "{user} が削除しました",
    "Restored by {user}" : "{user} が復元しました",
    "Renamed by {user}" : "{user} が作成しました",
    "Moved by {user}" : "{user} が移動しました",
    "\"remote user\"" : "\"リモートユーザー\"",
    "You created {file}" : "{file} を作成しました",
    "You created an encrypted file in {file}" : "{file} で暗号化ファイルを作成しました",
    "{user} created {file}" : "{user} が {file} を作成しました",
    "{user} created an encrypted file in {file}" : "{user}が{file}に暗号化ファイルを作成しました",
    "{file} was created in a public folder" : "公開フォルダーに {file} が作成されました",
    "You changed {file}" : "{file} を更新しました",
    "You changed an encrypted file in {file}" : "{file}で暗号化されたファイルを変更しました。",
    "{user} changed {file}" : "{user} が {file} を更新しました",
    "{user} changed an encrypted file in {file}" : "{user}が{file}に暗号化ファイルを変更しました",
    "You deleted {file}" : "{file} を削除しました",
    "You deleted an encrypted file in {file}" : "{file}で暗号化されたファイルを削除しました。",
    "{user} deleted {file}" : "{user} が {file} を削除しました",
    "{user} deleted an encrypted file in {file}" : "{user}が{file}で暗号化されたファイルを削除しました",
    "You restored {file}" : "{file} を復元しました",
    "{user} restored {file}" : "{user} が {file} を復元しました",
    "You renamed {oldfile} to {newfile}" : "{oldfile} を {newfile} に変更しました",
    "{user} renamed {oldfile} to {newfile}" : "{user} が {oldfile} を{newfile} に変更しました",
    "You moved {oldfile} to {newfile}" : "{oldfile} を {newfile} に移動しました",
    "{user} moved {oldfile} to {newfile}" : "{user} が {oldfile} を {newfile} に移動しました",
    "A file has been added to or removed from your <strong>favorites</strong>" : "<strong>お気に入り</strong>にファイルが追加または削除されたとき",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "ファイルまたはフォルダーが<strong>更新</ strong>されたか、<strong>名前が変更</strong>されたとき",
    "A new file or folder has been <strong>created</strong>" : "新しいファイルまたはフォルダーが<strong>作成</strong>されたとき",
    "A file or folder has been <strong>deleted</strong>" : "ファイルまたはフォルダーが<strong>削除</strong>されたとき",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "<strong>お気に入りファイル</strong>の作成と変更の通知を制限する<em>（ストリームのみ）</em>",
    "A file or folder has been <strong>restored</strong>" : "ファイルまたはフォルダーが<strong>復元</strong>されたとき",
    "Unlimited" : "無制限",
    "Upload (max. %s)" : "アップロード ( 最大 %s )",
    "File Management" : "ファイル管理",
    "File handling" : "ファイル操作",
    "Maximum upload size" : "最大アップロードサイズ",
    "max. possible: " : "最大容量: ",
    "Save" : "保存",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "PHP-FPM の場合は値を変更後、反映されるのに5分程度かかります。",
    "Missing permissions to edit from here." : "ここから編集するための権限がありません。",
    "%s of %s used" : "%s / %s 使用中",
    "%1$s%% of %2$s used" : "%2$s 中%1$s %%が使われています。",
    "%s used" : "%s 使用中",
    "Settings" : "設定",
    "Show hidden files" : "隠しファイルを表示",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">WebDAV 経由でファイルにアクセス</a>するにはこのアドレスを利用してください",
    "Toggle grid view" : "グリッド表示の切り替え",
    "Cancel upload" : "アップロードをキャンセル",
    "No files in here" : "ファイルがありません",
    "Upload some content or sync with your devices!" : "何かコンテンツをアップロードするか、デバイスからファイルを同期してください。",
    "No entries found in this folder" : "このフォルダーにはエントリーがありません",
    "Select all" : "すべて選択",
    "Upload too large" : "アップロードには大きすぎます。",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "アップロードしようとしているファイルは、このサーバーのファイルアップロード時の最大サイズを超えています。",
    "No favorites yet" : "まだお気に入りはありません",
    "Files and folders you mark as favorite will show up here" : "お気に入りに登録されたファイルやフォルダーは、ここに表示されます。",
    "Tags" : "タグ",
    "Deleted files" : "ゴミ箱",
    "Shares" : "共有",
    "Shared with others" : "他ユーザーと共有中",
    "Shared with you" : "他ユーザーがあなたと共有中",
    "Shared by link" : "URLリンクで共有中",
    "Deleted shares" : "削除された共有",
    "Text file" : "テキストファイル",
    "New text file.txt" : "新規のテキストファイル作成",
    "Target folder" : "対象フォルダー",
    "%1$s of %2$s used" : "%2$s 中%1$s が使われています。"
},
"nplurals=1; plural=0;");
